==> obiba_mica-7.x-22.3.tar.gz: obiba_mica/obiba_mica_app_angular/obiba_mica_app_angular.api.php <==
<?php
/**
 * Copyright (c) 2016 OBiBa. All rights reserved.
 *
 * This program and the accompanying materials
 * are made available under the terms of the GNU Public License v3.0.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file
 * Hooks provided by Obiba Mica app angular module.
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Load the menu paths on each module implementing angular app.
 *
 * @return array
 *   The array of menu as defined by Drupal menu system.
 */
function hook_load_menus() {
  $items = array();

  $items['given/path'] = array(
    'access callback' => TRUE,
    'title' => t('Title menu'),
  );
  return $items;
}

/**
 * Load angular application javascript within the module.
 */
function hook_get_js($weight_js) {
  if (current_path() == MicaClientPathProvider::CROSSTAB) {
    $module_path = drupal_get_path('module', 'obiba_mica_dataset');
    $js = file_scan_directory($module_path . '/js/app', '/.*\.js$/', array('key' => 'name'));
    ksort($js);
    foreach ($js as $file_js) {
      drupal_add_js($file_js->uri, array(
        'type' => 'file',
        'scope' => 'footer',
        'weight' => ++$weight_js,
      ));
    }
  }
  return ++$weight_js;
}

/**
 * The Angular application name to load on the main app.
 *
 * @return string
 *   The module angular name.
 */
function hook_get_ng_module_to_load() {
  if (current_path() == MicaClientPathProvider::CROSSTAB) {
    return 'mica.DatasetVariableCrosstab';
  }
  return FALSE;
}

/**
 * @} End of "addtogroup hooks".
 */

==> obiba_mica-7.x-30.3.tar.gz: obiba_mica/obiba_mica_app_angular/obiba_mica_app_angular.api.php <==
<?php
/**
 * Copyright (c) 2016 OBiBa. All rights reserved.
 *
 * This program and the accompanying materials
 * are made available under the terms of the GNU Public License v3.0.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file
 * Hooks provided by Obiba Mica app angular module.
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Load the menu paths on each module implementing angular app.
 *
 * @return array
 *   The array of menu as defined by Drupal menu system.
 */
function hook_load_menus() {
  $items = array();

  $items['given/path'] = array(
    'access callback' => TRUE,
    'title' => t('Title menu'),
  );
  return $items;
}

/**
 * Load angular application javascript within the module.
 */
function hook_get_js($weight_js) {
  if (current_path() == DrupalMicaDatasetResource::CROSSTAB) {
    $module_path = drupal_get_path('module', 'obiba_mica_dataset');
    $js = file_scan_directory($module_path . '/js/app', '/.*\.js$/', array('key' => 'name'));
    ksort($js);
    foreach ($js as $file_js) {
      drupal_add_js($file_js->uri, array(
        'type' => 'file',
        'scope' => 'footer',
        'weight' => ++$weight_js,
      ));
    }
  }
  return ++$weight_js;
}

/**
 * The Angular application name to load on the main app.
 *
 * @return string
 *   The module angular name.
 */
function hook_get_ng_module_to_load() {
  if (current_path() == DrupalMicaDatasetResource::CROSSTAB) {
    return 'mica.DatasetVariableCrosstab';
  }
  return FALSE;
}

/**
 * @} End of "addtogroup hooks".
 */
